@@ -1,7 +1,7 @@
 module Main.Sample where
 
 import qualified Data.Vector as B
-import Test.QuickCheck.Instances
+import Test.QuickCheck.Instances ()
 import qualified Test.Tasty.QuickCheck as C
 import qualified VectorBuilder.Builder as A
 import Prelude
@@ -29,7 +29,7 @@ toVector =
     Vector a -> a
     List a -> B.fromList a
 
-instance C.Arbitrary a => C.Arbitrary (Sample a) where
+instance (C.Arbitrary a) => C.Arbitrary (Sample a) where
   arbitrary =
     do
       constructorIndex <- C.choose (0 :: Int, 3)
@@ -38,3 +38,4 @@ instance C.Arbitrary a => C.Arbitrary (Sample a) where
         1 -> C.arbitrary >>= return . Singleton
         2 -> C.arbitrary >>= return . Vector
         3 -> C.arbitrary >>= return . List
+        _ -> error "Bug"
